leaftools.replace_leaves_in_expr_with_parallel_voices
=====================================================

.. autofunction:: abjad.tools.leaftools.replace_leaves_in_expr_with_parallel_voices.replace_leaves_in_expr_with_parallel_voices
